pub struct BigUintDivideHint;Implementations
Sourceimpl BigUintDivideHint
impl BigUintDivideHint
pub const fn new() -> Self
Sourcepub fn call(
builder: &CircuitBuilder,
dividend: &[Wire],
divisor: &[Wire],
) -> (Vec<Wire>, Vec<Wire>)
pub fn call( builder: &CircuitBuilder, dividend: &[Wire], divisor: &[Wire], ) -> (Vec<Wire>, Vec<Wire>)
BigUint division.
Returns (quotient, remainder) of the division of dividend by divisor.
This is a hint - a deterministic computation that happens only on the prover side.
The result should be additionally constrained by using bignum circuits to check that
remainder + divisor * quotient == dividend.