pub struct BigUintModPowHint;Implementations
Sourceimpl BigUintModPowHint
impl BigUintModPowHint
pub const fn new() -> Self
Sourcepub fn call(
builder: &CircuitBuilder,
base: &[Wire],
exp: &[Wire],
modulus: &[Wire],
) -> Vec<Wire>
pub fn call( builder: &CircuitBuilder, base: &[Wire], exp: &[Wire], modulus: &[Wire], ) -> Vec<Wire>
Modular exponentiation.
Computes (base^exp) % modulus.
This is a hint - a deterministic computation that happens only on the prover side.
The result should be additionally constrained using bignum circuits.