pub struct ModDivideHint;Expand description
ModDivide hint implementation.
Computes the modular quotient slope = dividend * divisor^{-1} (mod modulus) together with
the integer quotient witnessing the reduction slope * divisor = dividend + quotient * modulus. Both outputs are set to zero when divisor is not invertible modulo modulus
(e.g. divisor == 0 or gcd(divisor, modulus) > 1).
Implementations
Sourceimpl ModDivideHint
impl ModDivideHint
pub const fn new() -> Self
Sourcepub fn call(
builder: &CircuitBuilder,
dividend: &[Wire],
divisor: &[Wire],
modulus: &[Wire],
) -> (Vec<Wire>, Vec<Wire>)
pub fn call( builder: &CircuitBuilder, dividend: &[Wire], divisor: &[Wire], modulus: &[Wire], ) -> (Vec<Wire>, Vec<Wire>)
Modular division.
Computes dividend / divisor (mod modulus) = dividend * divisor^{-1} (mod modulus).
Returns a pair (quotient, slope) where slope is the modular quotient and quotient
is the non-negative integer satisfying slope * divisor = dividend + quotient * modulus.
Both are set to zero when divisor is not invertible modulo modulus (e.g. divisor == 0).
This is a hint - a deterministic computation that happens only on the prover side.
The result should be additionally constrained by using bignum circuits to check that
slope * divisor = dividend + quotient * modulus.