pub struct ModInverseHint;Expand description
ModInverse hint implementation
Implementations
Sourceimpl ModInverseHint
impl ModInverseHint
pub const fn new() -> Self
Sourcepub fn call(
builder: &CircuitBuilder,
base: &[Wire],
modulus: &[Wire],
) -> (Vec<Wire>, Vec<Wire>)
pub fn call( builder: &CircuitBuilder, base: &[Wire], modulus: &[Wire], ) -> (Vec<Wire>, Vec<Wire>)
Modular inverse.
Computes the modular inverse of base modulo modulus.
Returns a pair (quotient, inverse) where both numbers are Bézout coefficients when
base and modulus are coprime. Both numbers are set to zero if gcd(base, modulus) > 1.
This is a hint - a deterministic computation that happens only on the prover side.
The result should be additionally constrained by using bignum circuits to check that
base * inverse = 1 + quotient * modulus.